RobylonChatbotController class

Controller for imperative Chatbot control (open, close, toggle, isReady).

Constructors

RobylonChatbotController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach({VoidCallback? open, VoidCallback? close, VoidCallback? toggle, bool isReady()?}) → void
close() → void
isReady() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → void
toggle() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited