ErrorTrackingService class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(String apiKey, [dynamic userId]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendLog(LogPayload payload) Future<void>
toString() String
A string representation of this object.
inherited
trackError(Object error, String? componentName, Map<String, dynamic>? additionalInfo) Future<void>
trackInfo(String message, String? componentName, Map<String, dynamic>? additionalInfo) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ErrorTrackingService
no setter