ChatbotEventType enum
Chatbot event types emitted to onEvent and backend.
Values
- chatbotButtonLoaded → const ChatbotEventType
- chatbotButtonClicked → const ChatbotEventType
- chatbotOpened → const ChatbotEventType
- chatbotClosed → const ChatbotEventType
- chatbotAppReady → const ChatbotEventType
- chatbotLoaded → const ChatbotEventType
- chatInitialized → const ChatbotEventType
- sessionRefreshed → const ChatbotEventType
- chatInitializationFailed → const ChatbotEventType
- requestMicPermission → const ChatbotEventType
- micPermissionGranted → const ChatbotEventType
- micPermissionDenied → const ChatbotEventType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChatbotEventType> - A constant List of the values in this enum, in order of their declaration.